"use strict";
var JsonIncludePropertyFilter = (function () {
    function JsonIncludePropertyFilter(properties) {
        var _this = this;
        this.apply = function (source) {
            var destination = new Array();
            for (var _i = 0, _a = _this._properties; _i < _a.length; _i++) {
                var rule = _a[_i];
                _this._include(rule, source, destination);
            }
            return destination;
        };
        this._properties = properties;
    }
    JsonIncludePropertyFilter.prototype._include = function (rule, source, destination) {
        if (rule.match(JsonIncludePropertyFilter.ALL_PROPERTIES_REGEX)) {
            this._includeProperties(rule, source, destination);
        }
        else if (rule.match(JsonIncludePropertyFilter.ALL_ELEMENT_PROPERTIES_REGEX)) {
            this._includeRootProperties(rule, source, destination);
        }
        else {
            this._includeSpecificPath(rule, source, destination);
        }
    };
    JsonIncludePropertyFilter.prototype._includeProperties = function (rule, source, destination) {
        var formattedRule = rule.substr(0, rule.length - 2);
        for (var propertySourcePath in source) {
            var propertySourceValue = source[propertySourcePath];
            if (propertySourcePath.match("^" + formattedRule)) {
                destination[propertySourcePath] = propertySourceValue;
            }
        }
    };
    JsonIncludePropertyFilter.prototype._includeRootProperties = function (rule, source, destination) {
        var formattedRule = rule.substr(0, rule.length - 1);
        for (var propertySourcePath in source) {
            var formattedPropertySourcePath = propertySourcePath.replace(JsonIncludePropertyFilter.ARRAY_INDEX, JsonIncludePropertyFilter.STRING_EMPTY);
            var propertySourceValue = source[propertySourcePath];
            if (formattedRule === JsonIncludePropertyFilter.STRING_EMPTY) {
                if (propertySourcePath.split(JsonIncludePropertyFilter.PATH_SEPARATOR).length === 1) {
                    destination[propertySourcePath] = propertySourceValue;
                }
            }
            else {
                if (formattedPropertySourcePath.match("^" + formattedRule)) {
                    var splittedFormattedPropertySourcePath = formattedPropertySourcePath.split(".");
                    var splittedFormattedRule = formattedRule.split(".");
                    if (splittedFormattedPropertySourcePath.length === splittedFormattedRule.length) {
                        destination[propertySourcePath] = propertySourceValue;
                    }
                }
            }
        }
    };
    JsonIncludePropertyFilter.prototype._includeSpecificPath = function (rule, source, destination) {
        for (var propertySourcePath in source) {
            var formattedPropertySourcePath = propertySourcePath.replace(JsonIncludePropertyFilter.ARRAY_INDEX, JsonIncludePropertyFilter.STRING_EMPTY);
            if (rule === formattedPropertySourcePath) {
                destination[propertySourcePath] = source[propertySourcePath];
            }
        }
    };
    JsonIncludePropertyFilter.ALL_PROPERTIES_REGEX = /\*\*$/g;
    JsonIncludePropertyFilter.ALL_ELEMENT_PROPERTIES_REGEX = /\*$/g;
    JsonIncludePropertyFilter.ARRAY_INDEX = /\[[0-9]+\]/g;
    JsonIncludePropertyFilter.PATH_SEPARATOR = ".";
    JsonIncludePropertyFilter.STRING_EMPTY = "";
    return JsonIncludePropertyFilter;
}());
Object.defineProperty(exports, "__esModule", { value: true });
exports.default = JsonIncludePropertyFilter;
