"use strict";
var jsonSerializer_1 = require("./jsonSerializer");
var jsonExcludePropertyFilter_1 = require("./jsonExcludePropertyFilter");
var jsonIncludePropertyFilter_1 = require("./jsonIncludePropertyFilter");
var JsonPropertyFilter = (function () {
    function JsonPropertyFilter(args) {
        var properties = this._formatProperties(args);
        var propertiesToInclude = this._extractProperties(properties, [JsonPropertyFilter.INCLUDE_SYMBOL, ""]);
        var propertiesToExclude = this._extractProperties(properties, [JsonPropertyFilter.EXCLUDE_SYMBOL]);
        this._exclude = new jsonExcludePropertyFilter_1.default(propertiesToExclude);
        this._include = new jsonIncludePropertyFilter_1.default(propertiesToInclude);
    }
    JsonPropertyFilter.prototype.apply = function (source) {
        var keys = jsonSerializer_1.default.serializeToArray(source);
        var destination = new Array();
        destination = this._include.apply(keys);
        destination = this._exclude.apply(destination);
        var filtered = jsonSerializer_1.default.serializeToObject(destination);
        return filtered;
    };
    JsonPropertyFilter.prototype._extractProperties = function (properties, symbols) {
        var include = new Array();
        for (var _i = 0, properties_1 = properties; _i < properties_1.length; _i++) {
            var property = properties_1[_i];
            var formattedProperty = this._extractProperty(property, symbols);
            if (formattedProperty) {
                include.push(formattedProperty);
            }
        }
        return include;
    };
    JsonPropertyFilter.prototype._extractProperty = function (property, symbols) {
        for (var _i = 0, symbols_1 = symbols; _i < symbols_1.length; _i++) {
            var symbol = symbols_1[_i];
            var inProperty = property.indexOf(symbol);
            if (inProperty === 0) {
                return property.substring(symbol.length);
            }
        }
        return undefined;
    };
    JsonPropertyFilter.prototype._formatProperties = function (properties) {
        if (typeof properties === "string") {
            return properties.split(",");
        }
        else {
            return properties;
        }
    };
    JsonPropertyFilter.INCLUDE_SYMBOL = "+";
    JsonPropertyFilter.EXCLUDE_SYMBOL = "-";
    return JsonPropertyFilter;
}());
exports.JsonPropertyFilter = JsonPropertyFilter;
